@@ -34,7 +34,7 @@ GFile       *thunar_g_file_new_for_computer         (void);
 GFile       *thunar_g_file_new_for_network          (void);
 GFile       *thunar_g_file_new_for_bookmarks        (void);
 
-GFile       *thunar_g_file_new_for_symlink_target   (GFile                *file);
+GFile       *thunar_g_file_resolve_symlink          (GFile                *file);
 
 gboolean     thunar_g_file_is_root                  (GFile                *file);
 gboolean     thunar_g_file_is_trashed               (GFile                *file);
@@ -123,7 +123,6 @@ gboolean     thunar_g_file_is_in_xdg_data_dir          (GFile             *file)
 gboolean     thunar_g_file_is_desktop_file             (GFile             *file);
 char        *thunar_g_file_get_link_path_for_symlink   (GFile             *file_to_link,
                                                         GFile             *symlink);
-char        *thunar_g_file_get_resolved_path           (GFile             *file);
 G_END_DECLS
 
 #endif /* !__THUNAR_GIO_EXTENSIONS_H__ */
